/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.fragment.entry.processor.internal.util;

import com.liferay.info.formatter.InfoCollectionTextFormatter;
import com.liferay.info.type.Labeled;
import com.liferay.petra.string.StringPool;

import java.util.Collection;
import java.util.Locale;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author Jorge Ferrer
 */
public class CommaSeparatedInfoCollectionTextFormatter
	implements InfoCollectionTextFormatter<Object> {

	@Override
	public String format(Collection<Object> collection, Locale locale) {
		Stream<Object> stream = collection.stream();

		return stream.map(
			collectionItem -> {
				if (collectionItem instanceof Labeled) {
					Labeled collectionItemLabeled = (Labeled)collectionItem;

					return collectionItemLabeled.getLabel(locale);
				}

				return collectionItem.toString();
			}
		).collect(
			Collectors.joining(StringPool.COMMA_AND_SPACE)
		);
	}

}